@@ -3,6 +3,6 @@
 /* The name of this package (not localized) */
 var PACKAGE_NAME = 'cinnamon';
 /* The version of this package */
-var PACKAGE_VERSION = '6.4.10';
+var PACKAGE_VERSION = '6.6.3';
 /* 1 if networkmanager is available, 0 otherwise */
-var HAVE_NETWORKMANAGER = 1;
+var BUILT_NM_AGENT = 1;
